@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4009';
+our $VERSION = '0.4010';
 
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
@@ -405,7 +405,6 @@ sub pattern {
     $args{patterns}   ||= [];
     $args{beats}      ||= $self->beats;
     $args{negate}     ||= 0;
-    $args{count}      ||= 0;
     $args{repeat}     ||= 1;
 
     return unless @{ $args{patterns} };
@@ -437,7 +436,6 @@ sub pattern {
         for ( 1 .. $args{repeat} ) {
             for my $bit ( split //, $pattern ) {
                 $args{vary}{$bit}->($self);
-                $self->counter( $self->counter + $size ) if $args{count};
             }
         }
     }
@@ -603,7 +601,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4009
+version 0.4010
 
 =head1 SYNOPSIS
 
@@ -975,7 +973,7 @@ For example:
   patterns => [qw( 0101 0101 0110 0110 )],
 
 This method accumulates the number of beats in the object's B<counter>
-attribute, if the B<count> option is set.
+attribute.
 
 The B<vary> option is a hashref of coderefs, keyed by single character
 tokens, like the digits 0-9.  Each coderef duration should add up to
@@ -990,7 +988,6 @@ Defaults:
     duration: quarter-note
     beats: given by constructor
     repeat: 1
-    count: 0 ( keep track of the beat count)
     negate: 0 (flip the bit values)
     vary:
         0 => sub { $self->rest( $args{duration} ) },
